==> haskell-patience-0.3-8-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-patience.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 patience
version:              0.3
visibility:           public
id:                   patience-0.3-AEFu8V1Gv6zFbJllaUIZ0K
key:                  patience-0.3-AEFu8V1Gv6zFbJllaUIZ0K
license:              BSD-3-Clause
maintainer:           chessai <chessai1996@gmail.com>
author:
    Keegan McAllister <mcallister.keegan@gmail.com>
    chessai <chessai1996@gmail.com>

homepage:             https://github.com/chessai/patience
synopsis:             Patience diff and longest increasing subsequence
description:
    This library implements the \"patience diff\" algorithm, as well as the patience
    algorithm for the longest increasing subsequence problem.

    Patience diff computes the difference between two lists, for example the
    lines of two versions of a source file.  It provides a good balance of
    performance, nice output for humans, and implementation simplicity.  For more
    information, see <http://alfedenzo.livejournal.com/170301.html> and
    <http://bramcohen.livejournal.com/73318.html>.

category:             Algorithms, Text
abi:                  c606ff535902cd001edcb2e2f9b07bec
exposed:              True
exposed-modules:      Patience Patience.Map
import-dirs:          /usr/lib/ghc-9.0.1/site-local/patience-0.3
library-dirs:         /usr/lib/ghc-9.0.1/site-local/patience-0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/patience-0.3
hs-libraries:         HSpatience-0.3-AEFu8V1Gv6zFbJllaUIZ0K
depends:              base-4.15.0.0 containers-0.6.4.1
haddock-interfaces:   /usr/share/doc/haskell-patience/html/patience.haddock
haddock-html:         /usr/share/doc/haskell-patience/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-patience-0.3-9-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-patience.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 patience
version:              0.3
visibility:           public
id:                   patience-0.3-FMfjIM2j1dI2NNsx6NsXB6
key:                  patience-0.3-FMfjIM2j1dI2NNsx6NsXB6
license:              BSD-3-Clause
maintainer:           chessai <chessai1996@gmail.com>
author:
    Keegan McAllister <mcallister.keegan@gmail.com>
    chessai <chessai1996@gmail.com>

homepage:             https://github.com/chessai/patience
synopsis:             Patience diff and longest increasing subsequence
description:
    This library implements the \"patience diff\" algorithm, as well as the patience
    algorithm for the longest increasing subsequence problem.

    Patience diff computes the difference between two lists, for example the
    lines of two versions of a source file.  It provides a good balance of
    performance, nice output for humans, and implementation simplicity.  For more
    information, see <http://alfedenzo.livejournal.com/170301.html> and
    <http://bramcohen.livejournal.com/73318.html>.

category:             Algorithms, Text
abi:                  a3fb0ee68d367b4995309b125dcc83fc
exposed:              True
exposed-modules:      Patience Patience.Map
import-dirs:          /usr/lib/ghc-9.0.2/site-local/patience-0.3
library-dirs:         /usr/lib/ghc-9.0.2/site-local/patience-0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/patience-0.3
hs-libraries:         HSpatience-0.3-FMfjIM2j1dI2NNsx6NsXB6
depends:              base-4.15.1.0 containers-0.6.4.1
haddock-interfaces:   /usr/share/doc/haskell-patience/html/patience.haddock
haddock-html:         /usr/share/doc/haskell-patience/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
